@@ -1,7 +1,8 @@
 ## File Name: starts_uni_cov.R
-## File Version: 0.06
+## File Version: 0.11
 
-starts_uni_cov <- function(W , var_trait , var_ar , var_state , a , time_index = NULL )
+starts_uni_cov <- function(W , var_trait , var_ar , var_state , a , time_index = NULL ,
+	add_meas_error = NULL )
 {
 	covmat <- matrix( var_trait , nrow=W , ncol=W )  
 	for (ii in 1:W){
@@ -14,6 +15,9 @@ starts_uni_cov <- function(W , var_trait , var_ar , var_state , a , time_index =
 		}
 	}
 	covmat <- covmat + matr
+	if ( ! is.null(add_meas_error) ){
+		diag(covmat) <- diag(covmat) + add_meas_error
+	}	
 	if ( ! is.null(time_index) ){
 		covmat <- covmat[ time_index , time_index ]
 	}	
