@@ -1,8 +1,8 @@
 ## File Name: summary.starts_uni.R
-## File Version: 0.18
+## File Version: 0.26
 
 #############################################################
-summary.starts_uni <- function( object , digits=3 , file=NULL ,... )
+summary.starts_uni <- function( object , digits=3 , file=NULL, print_call=TRUE, ... )
 {
     # open sink
     CDM::osink( file = file , suffix = paste0( "__SUMMARY.Rout") )
@@ -20,7 +20,9 @@ summary.starts_uni <- function( object , digits=3 , file=NULL ,... )
 	cat( "Used function =" , object$used_function , "\n\n" )
 	
 	#-- print call
-	sirt::sirt_summary_print_call(CALL=object$CALL)				
+	if (print_call){
+		sirt::sirt_summary_print_call(CALL=object$CALL)				
+	}
 	   
 	#-- print computation time
 	starts_summary_print_computation_time(object=object)
@@ -73,20 +75,31 @@ summary.starts_uni <- function( object , digits=3 , file=NULL ,... )
 		obji$effSize <- round( obji$effSize )		
 	}			
 	sirt::sirt_summary_print_objects(obji=obji, from=2, digits=3, rownames_null=TRUE)	
-	
-	
+
 	cat("-----------------------------------------------------------------\n")
-	cat("Model Fit \n\n")	
+	cat("Variance Proportions \n")	
 
-	digits_fit <- 3
+	if (object$use_pmle){ 
+		obji <- object$var_prop
+	}
+	if (object$use_amh){ 
+		obji <- object$var_prop
+		obji <- obji[, intersect(vars, colnames(obji)) ]
+		obji$effSize <- round( obji$effSize )		
+	}			
+	sirt::sirt_summary_print_objects(obji=obji, from=2, digits=3, rownames_null=TRUE)	
+			
+	if ( ! object$some_missings ){
+		cat("-----------------------------------------------------------------\n")
+		cat("Model Fit \n\n")	
+		digits_fit <- 3
+		cat( paste0("Chi square test of model fit: \nChi2(df=", object$model_fit$df_sem , 
+					")=" , round( object$model_fit$chisq , digits_fit ) , ", p=" , 
+					round( object$model_fit$p_chisq , digits_fit ) , "\n\n") )
+		cat( "SRMR =" , round( object$model_fit$SRMR , digits_fit ) , "\n" )  
+		cat( "RMSEA =" , round( object$model_fit$RMSEA , digits_fit ) , "\n" )  
+	}
 
-	cat( paste0("Chi square test of model fit: \nChi2(df=", object$model_fit$df_sem , 
-				")=" , round( object$model_fit$chisq , digits_fit ) , ", p=" , 
-				round( object$model_fit$p_chisq , digits_fit ) , "\n\n") )
-	cat( "SRMR =" , round( object$model_fit$SRMR , digits_fit ) , "\n" )  
-	cat( "RMSEA =" , round( object$model_fit$RMSEA , digits_fit ) , "\n" )  
-	
-	invisible(obji)
 	# close sink
     CDM::csink( file = file )		
 	
